pub enum DecodeDifferent<B, O>where
B: 'static,
O: 'static,{
Encode(B),
Decoded(O),
}Expand description
A type that decodes to a different type than it encodes. The user needs to make sure that both types use the same encoding.
For example a &'static [ &'static str ] can be decoded to a Vec<String>.
Variants