pub struct ErrorMetadata {
pub name: DecodeDifferent<&'static str, String>,
pub documentation: DecodeDifferentArray<&'static str, String>,
}Expand description
All the metadata about a module error.
Fields
name: DecodeDifferent<&'static str, String>documentation: DecodeDifferentArray<&'static str, String>Trait Implementations
Sourceimpl Clone for ErrorMetadata
impl Clone for ErrorMetadata
Sourcefn clone(&self) -> ErrorMetadata
fn clone(&self) -> ErrorMetadata
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ErrorMetadata
impl Debug for ErrorMetadata
Sourceimpl Decode for ErrorMetadata
impl Decode for ErrorMetadata
Sourceimpl Encode for ErrorMetadata
impl Encode for ErrorMetadata
Sourcefn encode_to<__CodecOutputEdqy: Output + ?Sized>(
&self,
__codec_dest_edqy: &mut __CodecOutputEdqy,
)
fn encode_to<__CodecOutputEdqy: Output + ?Sized>( &self, __codec_dest_edqy: &mut __CodecOutputEdqy, )
Convert self to a slice and append it to the destination.
Sourcefn size_hint(&self) -> usize
fn size_hint(&self) -> usize
If possible give a hint of expected size of the encoding. Read more
Sourcefn using_encoded<R, F>(&self, f: F) -> R
fn using_encoded<R, F>(&self, f: F) -> R
Convert self to a slice and then invoke the given closure with it.
Sourcefn encoded_size(&self) -> usize
fn encoded_size(&self) -> usize
Calculates the encoded size. Read more
impl EncodeLike for ErrorMetadata
impl Eq for ErrorMetadata
Sourceimpl PartialEq for ErrorMetadata
impl PartialEq for ErrorMetadata
Sourceimpl Serialize for ErrorMetadata
impl Serialize for ErrorMetadata
impl StructuralPartialEq for ErrorMetadata