pub struct EventMetadata {
pub name: DecodeDifferent<&'static str, String>,
pub arguments: DecodeDifferentArray<&'static str, String>,
pub documentation: DecodeDifferentArray<&'static str, String>,
}Expand description
All the metadata about an event.
Fields
name: DecodeDifferent<&'static str, String>arguments: DecodeDifferentArray<&'static str, String>documentation: DecodeDifferentArray<&'static str, String>Trait Implementations
Sourceimpl Clone for EventMetadata
impl Clone for EventMetadata
Sourcefn clone(&self) -> EventMetadata
fn clone(&self) -> EventMetadata
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EventMetadata
impl Debug for EventMetadata
Sourceimpl Decode for EventMetadata
impl Decode for EventMetadata
Sourceimpl Encode for EventMetadata
impl Encode for EventMetadata
Sourcefn encode_to<__CodecOutputEdqy: Output + ?Sized>(
&self,
__codec_dest_edqy: &mut __CodecOutputEdqy,
)
fn encode_to<__CodecOutputEdqy: Output + ?Sized>( &self, __codec_dest_edqy: &mut __CodecOutputEdqy, )
Convert self to a slice and append it to the destination.
Sourcefn size_hint(&self) -> usize
fn size_hint(&self) -> usize
If possible give a hint of expected size of the encoding. Read more
Sourcefn using_encoded<R, F>(&self, f: F) -> R
fn using_encoded<R, F>(&self, f: F) -> R
Convert self to a slice and then invoke the given closure with it.
Sourcefn encoded_size(&self) -> usize
fn encoded_size(&self) -> usize
Calculates the encoded size. Read more
impl EncodeLike for EventMetadata
impl Eq for EventMetadata
Sourceimpl PartialEq for EventMetadata
impl PartialEq for EventMetadata
Sourceimpl Serialize for EventMetadata
impl Serialize for EventMetadata
impl StructuralPartialEq for EventMetadata