pub struct FnEncode<E>(pub fn() -> E)
where
E: Encode + 'static;Expand description
Newtype wrapper for support encoding functions (actual the result of the function).
Tuple Fields
0: fn() -> ETrait Implementations
Sourceimpl<E: Encode> Encode for FnEncode<E>
impl<E: Encode> Encode for FnEncode<E>
Sourcefn encode_to<W: Output + ?Sized>(&self, dest: &mut W)
fn encode_to<W: Output + ?Sized>(&self, dest: &mut W)
Convert self to a slice and append it to the destination.
Sourcefn size_hint(&self) -> usize
fn size_hint(&self) -> usize
If possible give a hint of expected size of the encoding. Read more
Sourcefn using_encoded<R, F>(&self, f: F) -> R
fn using_encoded<R, F>(&self, f: F) -> R
Convert self to a slice and then invoke the given closure with it.
Sourcefn encoded_size(&self) -> usize
fn encoded_size(&self) -> usize
Calculates the encoded size. Read more
impl<E: Encode> EncodeLike for FnEncode<E>
impl<E> Eq for FnEncode<E>