pub struct FunctionMetadata {
pub name: DecodeDifferent<&'static str, String>,
pub arguments: DecodeDifferentArray<FunctionArgumentMetadata>,
pub documentation: DecodeDifferentArray<&'static str, String>,
}Expand description
All the metadata about a function.
Fields
name: DecodeDifferent<&'static str, String>arguments: DecodeDifferentArray<FunctionArgumentMetadata>documentation: DecodeDifferentArray<&'static str, String>Trait Implementations
Sourceimpl Clone for FunctionMetadata
impl Clone for FunctionMetadata
Sourcefn clone(&self) -> FunctionMetadata
fn clone(&self) -> FunctionMetadata
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FunctionMetadata
impl Debug for FunctionMetadata
Sourceimpl Decode for FunctionMetadata
impl Decode for FunctionMetadata
Sourceimpl Encode for FunctionMetadata
impl Encode for FunctionMetadata
Sourcefn encode_to<__CodecOutputEdqy: Output + ?Sized>(
&self,
__codec_dest_edqy: &mut __CodecOutputEdqy,
)
fn encode_to<__CodecOutputEdqy: Output + ?Sized>( &self, __codec_dest_edqy: &mut __CodecOutputEdqy, )
Convert self to a slice and append it to the destination.
Sourcefn size_hint(&self) -> usize
fn size_hint(&self) -> usize
If possible give a hint of expected size of the encoding. Read more
Sourcefn using_encoded<R, F>(&self, f: F) -> R
fn using_encoded<R, F>(&self, f: F) -> R
Convert self to a slice and then invoke the given closure with it.
Sourcefn encoded_size(&self) -> usize
fn encoded_size(&self) -> usize
Calculates the encoded size. Read more
Sourceimpl PartialEq for FunctionMetadata
impl PartialEq for FunctionMetadata
Sourceimpl Serialize for FunctionMetadata
impl Serialize for FunctionMetadata
impl EncodeLike for FunctionMetadata
impl Eq for FunctionMetadata
impl StructuralPartialEq for FunctionMetadata