pub struct ModuleConstantMetadata {
pub name: DecodeDifferent<&'static str, String>,
pub ty: DecodeDifferent<&'static str, String>,
pub value: ByteGetter,
pub documentation: DecodeDifferentArray<&'static str, String>,
}Expand description
All the metadata about one module constant.
Fields
name: DecodeDifferent<&'static str, String>ty: DecodeDifferent<&'static str, String>value: ByteGetterdocumentation: DecodeDifferentArray<&'static str, String>Trait Implementations
Sourceimpl Clone for ModuleConstantMetadata
impl Clone for ModuleConstantMetadata
Sourcefn clone(&self) -> ModuleConstantMetadata
fn clone(&self) -> ModuleConstantMetadata
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ModuleConstantMetadata
impl Debug for ModuleConstantMetadata
Sourceimpl Decode for ModuleConstantMetadata
impl Decode for ModuleConstantMetadata
Sourceimpl Encode for ModuleConstantMetadata
impl Encode for ModuleConstantMetadata
Sourcefn encode_to<__CodecOutputEdqy: Output + ?Sized>(
&self,
__codec_dest_edqy: &mut __CodecOutputEdqy,
)
fn encode_to<__CodecOutputEdqy: Output + ?Sized>( &self, __codec_dest_edqy: &mut __CodecOutputEdqy, )
Convert self to a slice and append it to the destination.
Sourcefn size_hint(&self) -> usize
fn size_hint(&self) -> usize
If possible give a hint of expected size of the encoding. Read more
Sourcefn using_encoded<R, F>(&self, f: F) -> R
fn using_encoded<R, F>(&self, f: F) -> R
Convert self to a slice and then invoke the given closure with it.
Sourcefn encoded_size(&self) -> usize
fn encoded_size(&self) -> usize
Calculates the encoded size. Read more
Sourceimpl PartialEq for ModuleConstantMetadata
impl PartialEq for ModuleConstantMetadata
Sourceimpl Serialize for ModuleConstantMetadata
impl Serialize for ModuleConstantMetadata
impl EncodeLike for ModuleConstantMetadata
impl Eq for ModuleConstantMetadata
impl StructuralPartialEq for ModuleConstantMetadata