pub struct ModuleMetadata {
pub name: DecodeDifferent<&'static str, String>,
pub storage: Option<DecodeDifferent<FnEncode<StorageMetadata>, StorageMetadata>>,
pub calls: Option<DecodeDifferent<FnEncode<&'static [FunctionMetadata]>, Vec<FunctionMetadata>>>,
pub event: Option<DecodeDifferent<FnEncode<&'static [EventMetadata]>, Vec<EventMetadata>>>,
pub constants: DecodeDifferent<FnEncode<&'static [ModuleConstantMetadata]>, Vec<ModuleConstantMetadata>>,
pub errors: DecodeDifferent<FnEncode<&'static [ErrorMetadata]>, Vec<ErrorMetadata>>,
pub index: u8,
}Expand description
All metadata about an runtime module.
Fields
name: DecodeDifferent<&'static str, String>storage: Option<DecodeDifferent<FnEncode<StorageMetadata>, StorageMetadata>>calls: Option<DecodeDifferent<FnEncode<&'static [FunctionMetadata]>, Vec<FunctionMetadata>>>event: Option<DecodeDifferent<FnEncode<&'static [EventMetadata]>, Vec<EventMetadata>>>constants: DecodeDifferent<FnEncode<&'static [ModuleConstantMetadata]>, Vec<ModuleConstantMetadata>>errors: DecodeDifferent<FnEncode<&'static [ErrorMetadata]>, Vec<ErrorMetadata>>index: u8Define the index of the module, this index will be used for the encoding of module event, call and origin variants.